Crate timecard

Crate timecard 

timecard is a library that makes it easy to build applications that keep track of time, such as timecard-cli.

This is primarily built as a Rust learning project, while also creating a tool that’s personally useful.

Re-exports

pub use timecard::TimeEntry;
pub use timecard::Timecard;

Modules

error
Result error definitions
timecard
Start with Timecard::new(Vec<TimeEntry>), the rest of the functions will explain themselves.

Constants

VERSION
The current version of this library